/*!
Copyright 2018(c) Analog Devices, Inc.

LTC5555: Programmable Downconverting Mixer with IF DVGA

@verbatim

The LTC5555 programmable gain downconverting mixer is ideal
for receivers that require precise gain setting. The IC 
incorporates an active mixer and a digital IF VGA with
15.5dB gain control range. The IF gain is programmed in
0.5dB steps through the SPI or parallel interface. 
A reduced power mode is also available.

SPI DATA FORMAT (MSB First):

Data In  :   RP[0] X  X  IF[4] IF[3] IF[2] IF[1] IF[0] 
            |------- CONTROL BITS FOR LTC5555 -------|

RP : Reduced Power Mode Control Bit
IF : IF Attenuation Control Bits

@endverbatim

https://www.analog.com/en/products/ltc5555.html

All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:
 - Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.
 - Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in
   the documentation and/or other materials provided with the
   distribution.
 - Neither the name of Analog Devices, Inc. nor the names of its
   contributors may be used to endorse or promote products derived
   from this software without specific prior written permission.
 - The use of this software may or may not infringe the patent rights
   of one or more patent holders.  This license does not release you
   from the requirement that you obtain separate licenses from these
   patent holders to use this software.
 - Use of the software either in source or binary form, must be run
   on or directly connected to an Analog Devices Inc. component.

THIS SOFTWARE IS PROVIDED BY ANALOG DEVICES "AS IS" AND ANY EXPRESS OR
IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, NON-INFRINGEMENT,
MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
IN NO EVENT SHALL ANALOG DEVICES BE LIABLE FOR ANY DIRECT, INDIRECT,
INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
LIMITED TO, INTELLECTUAL PROPERTY RIGHTS, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

/*! @file
    @ingroup LTC5555
    Header File for LTC5555: Dual Programmable Downconverting Mixer with IF DVGAs
*/

#ifndef LTC5555_H
#define LTC5555_H

#include <SPI.h>

//! Define the SPI CS pin
#ifndef LTC5555_CS
#define LTC5555_CS QUIKEVAL_CS
#endif

//! @name LTC5555 Reduced power mode configuration bits.
//! @{
#define LTC5555_FULL_POWER      0x00
#define LTC5555_REDUCED_POWER   0x80
//! @}

//! Writes to the LTC5555 twice and reads back the last byte to make sure the
//! LTC5555 was loaded properly
//! @return void
void LTC5555_write(
    uint8_t cs,                  //! Chip Select pin
    uint8_t tx,                 //! Word to be transmitted
    uint8_t *rx                 //! Output pointer
    );

//! Take user inputs and apply the settings to the mixer
//! @return Readback after writing settings to the mixer
uint8_t LTC5555_settings();

//! Function to get data from user for power mode
//! @return uint8_t
uint8_t LTC5555_get_power_mode(
    char *prompt     //! Prompt to ask for the desired power mode
    );

//! Get attenuation value from user
//! @return uint8_t
uint8_t LTC5555_get_att(
    char *prompt     //! Prompt to ask for the desired attenuation
    );

//! Decode the register value read from the LTC5555
//! @return void
void LTC5555_decode_output(
    uint8_t output   //! Raw output from the LTC5555 to decode
    );

#endif  // LTC5555_H
